@@ -1,22 +1,36 @@
+import time
+
 from django.test import TestCase
-from nose.tools import eq_, ok_
+from nose.tools import ok_
 from django.core.cache import cache
 from django.core.management import call_command
-from django.test import TestCase
 from io import StringIO
-from fancy_cache.middleware import REMEMBERED_URLS_KEY
+from fancy_cache.constants import REMEMBERED_URLS_KEY
 
 
 class TestBaseCommand(TestCase):
     def setUp(self):
+        expiration_time = int(time.time()) + 5
         self.urls = {
-            "/page1.html": "key1",
-            "/page2.html": "key2",
-            "/page3.html?foo=bar": "key3",
-            "/page3.html?foo=else": "key4",
+            "/page1.html": (
+                "key1",
+                expiration_time,
+            ),
+            "/page2.html": (
+                "key2",
+                expiration_time,
+            ),
+            "/page3.html?foo=bar": (
+                "key3",
+                expiration_time,
+            ),
+            "/page3.html?foo=else": (
+                "key4",
+                expiration_time,
+            ),
         }
         for key, value in self.urls.items():
-            cache.set(value, key)
+            cache.set(value[0], key)
         cache.set(REMEMBERED_URLS_KEY, self.urls, 5)
 
     def tearDown(self):
